@@ -3,7 +3,7 @@ package HTTP::Headers::Auth;
 use strict;
 use warnings;
 
-our $VERSION = "6.09";
+our $VERSION = '6.14';
 
 use HTTP::Headers;
 
@@ -98,3 +98,30 @@ sub www_authenticate    { shift->_authenticate("WWW-Authenticate", @_)   }
 sub proxy_authenticate  { shift->_authenticate("Proxy-Authenticate", @_) }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+HTTP::Headers::Auth
+
+=head1 VERSION
+
+version 6.14
+
+=head1 AUTHOR
+
+Gisle Aas <gisle@activestate.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1994-2017 by Gisle Aas.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
