@@ -3,7 +3,7 @@ package HTTP::Headers::Util;
 use strict;
 use warnings;
 
-our $VERSION = "6.09";
+our $VERSION = '6.14';
 
 use base 'Exporter';
 
@@ -93,12 +93,18 @@ sub join_header_words
 
 1;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 HTTP::Headers::Util - Header value parsing utility functions
 
+=head1 VERSION
+
+version 6.14
+
 =head1 SYNOPSIS
 
   use HTTP::Headers::Util qw(split_header_words);
@@ -114,7 +120,6 @@ The following functions are available:
 
 =over 4
 
-
 =item split_header_words( @header_values )
 
 This function will parse the header values given as argument into a
@@ -188,10 +193,21 @@ will both return the string:
 
 =back
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright 1997-1998, Gisle Aas
+Gisle Aas <gisle@activestate.com>
 
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1994-2017 by Gisle Aas.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+__END__
+
+
+#ABSTRACT: Header value parsing utility functions
 
